ex_changerate v0.1.1 ExChangerate.SupportedSymbols

Enables the use of Supported Symbols Endpoint

Note from documentaion: API comes with a constantly updated endpoint returning all available currencies. To access this list, make a request to the API's symbols endpoint.

Link to this section Summary

Link to this section Functions