ex_changerate v0.1.1 ExChangerate.Timeseries
Enables the use of Timeseries Endpoint
Note from documentation: Timeseries endpoint are for daily historical rates between two dates of your choice, with a maximum time frame of 365 days.
Link to this section Summary
Link to this section Functions
Link to this function
get()
Link to this function
get(options)
Link to this function