ex_changerate v0.1.1 ExChangerate.ConvertCurrency
Enables the use of Convert Endpoint
Note from documentation: Currency conversion endpoint, can be used to convert any amount from one currency to another. In order to convert currencies, please use the API's convert endpoint, append the from and to parameters and set them to your preferred base and target currency codes.
Link to this section Summary
Link to this section Functions
Link to this function
get()
Link to this function
get(options)
Link to this function