ex_changerate v0.1.1 ExChangerate.Fluctuation
Enables the use of Fluctuation Endpoint
Note from documentation: Using the fluctuation endpoint you will be able to retrieve information about how currencies fluctuate on a day-to-day basis. To use this feature, simply append a start_date and end_date and choose which currencies (symbols) you would like to query the API for. Please note that the maximum allowed timeframe is 365 days.
Link to this section Summary
Link to this section Functions
Link to this function
get()
Link to this function
get(options)
Link to this function