ex_changerate v0.1.1 ExChangerate.HistoricalRates
Enables the use of Historical Rates Endpoint
Note from documentation: Historical rates are available for most currencies all the way back to the year of 1999. You can query the API for historical rates by appending a date (format YYYY-MM-DD) to the base URL.
Link to this section Summary
Link to this section Functions
Link to this function
get()
Link to this function
get(options)
Link to this function